#
# spec file for package eom
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define typelib typelib-1_0-Eom-1_0
%define _version 1.20
Name:           eom
Version:        1.20.0
Release:        lp151.2.4
Summary:        MATE Desktop graphics viewer
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE eom-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch0:         eom-gtk-3.20.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjpeg-devel
BuildRequires:  libxml2-python
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
Requires:       mate-desktop-gsettings-schemas >= %{_version}
Recommends:     %{name}-lang
# mate-image-viewer was last used in openSUSE 13.1.
Provides:       mate-image-viewer = %{version}
Obsoletes:      mate-image-viewer < %{version}
Obsoletes:      mate-image-viewer-lang < %{version}
%glib2_gsettings_schema_requires

%description
The Eye of MATE is a simple graphics viewer for the MATE Desktop
which uses the gdk-pixbuf library. It can deal with large images,
and zoom and scroll with constant memory usage. Its goals are
simplicity and standards compliance.

%lang_package

%package devel
Summary:        MATE Desktop graphics viewer development files
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
# mate-image-viewer-devel was last used in openSUSE 13.1.
Provides:       mate-image-viewer-devel = %{version}
Obsoletes:      mate-image-viewer-devel < %{version}

%description devel
The Eye of MATE is a simple graphics viewer for the MATE Desktop
which uses the gdk-pixbuf library. It can deal with large images,
and zoom and scroll with constant memory usage. Its goals are
simplicity and standards compliance.

%package -n %{typelib}
Summary:        MATE Desktop graphics viewer typelib
Group:          System/Libraries

%description -n %{typelib}
The Eye of MATE is a simple graphics viewer for the MATE Desktop
which uses the gdk-pixbuf library. It can deal with large images,
and zoom and scroll with constant memory usage. Its goals are
simplicity and standards compliance.

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name} \
  --disable-python
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file %{name}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS README
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/*.xml
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_datadir}/help/C/%{name}/

%files lang -f %{name}.lang

%files devel
%{_includedir}/%{name}-2.20/
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/gir-1.0/Eom-1.0.gir
%{_datadir}/gtk-doc/html/%{name}/

%files -n %{typelib}
%{_libdir}/girepository-1.0/Eom-1.0.typelib

%changelog
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * EomThumbView, EomScrollView: Replace the deprecated
    gtk_menu_popup() function.
  * UI: Avoid using deprecaded widgets.
  * Fix a few GtkStock deprecations.
  * A bunch of instrospection warning fixes.
  * EomScrollView: Fix the override_background deprecated call.
  * EomPropertiesDialog: Fix deprecation warnings.
  * EomThumbNav: Fix a deprecated function warning.
  * EomScrollView: Switch from GdkDeviceManager to GdkSeat.
  * settings: Use the rgb colour definition as defaults.
  * EomFileChooser: Use MateThumbnailFactory to create the preview
    image.
  * EomPropertiesDialog: Allow RGBA for transparent background
    colour.
  * preferences-ui: Drop usage of MateColorButton.
  * EomScrollView: Switch to GdkRGBA for background and transparent
    colours.
  * EomPrintPreview: Avoid unnecessary colour parsing.
  * toolbar-editor: Avoid deprecated GtkAlignment.
  * gtk 3.22: Avoid deprecated gdk_screen_get_monitor_ functions.
  * Don't use deprecated gtk_show_uri().
  * Avoid deprecated gdk_screen_get_number().
  * print-preview: Replace custom code with a GDK function call.
  * Update translations.
- Add eom-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20 support.
* Wed Nov  8 2017 sor.alexei@meowr.ru
- Update to version 1.18.3:
  * Fix typo in function annotation.
  * Fix warning on closing empty window with multiple eom windows.
  * Update translations.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * EomWindow: Set file open dialogue transient for its parent
    window.
  * EomCloseConfirmationDialog: Set max width chars for primary
    label.
  * EomCloseConfirmationDialog: Fix size request for the image list.
  * Printing paper orientation should default based on image
    dimensions.
  * Avoid recompressing JPEGs as PNG when printing.
  * Other bug fixes.
  * Update translations.
* Wed Apr  5 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Bring eom-image.c's SVG handling up to date, properly
    recognise svgz filetypes.
  * eom_uri_converter: GList leak fix.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require libmate-desktop >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Drop Python bindings and the --enable-python build option.
  * Port the plugin system and plugins to libpeas.
  * Some code and docs cleanups.
  * Update translations.
* Wed Feb  8 2017 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Prefs dialogue: Fix runtime warnings.
  * Fix the auto-reload of externally modified images.
  * Fix a memleak when loading SVG fails.
  * GTK+3: Force the X11 backend.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Fix possible out-of-bounds writes in error message area.
  * Some cleanups.
  * Update translations.
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * Fix zoom and scroll performance on large images.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Fix new windows not getting focus.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Auto-reload unmodified images when their file is changed.
  * GTK+3: Add CSS name EggToolbarEditor for Gtk 3.20.
  * GTK+3: Fix SVG rendering.
  * Some more fixes and cleanups.
  * Update translations.
  * Fix Changelog generation.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * Avoid integer overflow when allocating a large block of memory.
  * Use org.gnome.SessionManager DBus name to inhibit screensaver.
  * totem-screensaver: Don't use old API and add ref to TotemScrsaver.
  * totem-screensaver: Fix assertions on entry to TotemScrsaver
    methods.
  * GTK+3: Add eom-window style class at top level.
  * Fix build warnings and remove useless nested #if.
* Fri Feb 19 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Fix compilation with enabled GObject Introspection.
  * Fix GTK+3 build when --without-cms is set.
  * Gtk3: Fix several deprecations.
  * Drop MateConf migration script.
  * Use _XOPEN_SOURCE_EXTENDED as OpenBSD needs it for strptime.
- Remove Python bindings: imcompatible with Gtk3.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 1.12.2:
  * Print preview: avoid integer overflow when allocating a large
    block of memory.
  * Fix build with introspection enabled.
  * Fix GTK+3 build when --without-cms is set.
  * Some more fixes.
- Remove eom-fix-introspection.patch: merged upstream.
* Mon Dec  7 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Fix shortcuts for several menu items in en_US locale.
  * Some more fixes and cleanups.
- Enable GObject Introspection.
- Add eom-fix-introspection.patch: fixes compilation with
  GObject Introspection enabled.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Thu Oct 15 2015 sor.alexei@meowr.ru
- Update to 1.11.0.
* Thu Oct  8 2015 sor.alexei@meowr.ru
- Update to 1.10.5:
  * Fix Gtk3 build.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Update to 1.10.4:
  * EomScrollView: clip all types of images to the visible image area.
  * EomScrollView: enable double buffering.
  * Bump GLib/GIO required version to 2.36.
  * Drop useless dependency on mate-icon-theme.
  * Fix build with libexif when prefix is not /usr.
  * Some annotation fixes.
  * Some GTK+3 fixes and improvements.
* Wed Jul 15 2015 sor.alexei@meowr.ru
- Update to 1.10.3:
  * Fix scroll issues during zoom.
  * Multiple help fixes.
* Thu Jun 18 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Fix gschema translations.
  * Gtk3 fixes and improvements.
* Sat Jun 13 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Bugfixes.
  * Update translations.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.1):
  * Bugfixes.
  * Improvements taken from eog.
  * Update translations.
- Spec cleanup.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.1
  * ChangeLog is empty
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + ChangeLog is empty
- Fix version requirements
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Update scrollbars when display is resized in "normal size" mode
  + Fix hyphen-as-minus-sign issues
    closes #47 (https://github.com/mate-desktop/eom/issues/47)
* Fri Sep  5 2014 p.drouand@gmail.com
- Fix mate-desktop-gsettings-schemas version requirement
* Wed Mar 12 2014 p.drouand@gmail.com
- Fix conflicts with mate-image-viewer
- Fix license; a library is released under LGPL-2.1+ and the rest
  under GPL-2.0+
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Fri Feb 14 2014 p.drouand@gmail.com
- Initial release (version 1.7.0)
